==> rendition-12.0.0.tgz: package/dist_esm5/components/Copy/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import { faCopy } from '@fortawesome/free-regular-svg-icons/faCopy';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import copyToClipboard from 'copy-to-clipboard';
import * as React from 'react';
import styled from 'styled-components';
import { px, stopEvent } from '../../utils';
import { Box } from '../Box';
import { Flex } from '../Flex';
var ClipboardContainer = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tcursor: pointer;\n\t/* We want the clipboard icon slightly smaller, but it should be the same height as normal text so it lines up nicely */\n\tfont-size: 0.875em;\n\tline-height: ", ";\n"], ["\n\tcursor: pointer;\n\t/* We want the clipboard icon slightly smaller, but it should be the same height as normal text so it lines up nicely */\n\tfont-size: 0.875em;\n\tline-height: ", ";\n"])), function (props) { return px(props.theme.lineHeight * props.theme.font[1]); });
var CopyContainer = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t", " {\n\t\tdisplay: ", ";\n\t}\n\n\t&:hover {\n\t\t", " {\n\t\t\tdisplay: inline;\n\t\t}\n\t}\n"], ["\n\t", " {\n\t\tdisplay: ", ";\n\t}\n\n\t&:hover {\n\t\t", " {\n\t\t\tdisplay: inline;\n\t\t}\n\t}\n"])), ClipboardContainer, function (props) { return (props.show === 'always' ? 'inline' : 'none'); }, ClipboardContainer);
export default (function (_a) {
    var content = _a.content, show = _a.show, children = _a.children, onClick = _a.onClick, otherProps = __rest(_a, ["content", "show", "children", "onClick"]);
    var normalizedText = (content || '').toString().trim();
    return (React.createElement(CopyContainer, __assign({ show: !!children ? show : 'always', flexDirection: "row", flexWrap: "nowrap" }, otherProps),
        children,
        React.createElement(ClipboardContainer, { mx: 2, tooltip: { text: 'Copied!', trigger: 'click' }, onClick: function (e) {
                stopEvent(e);
                copyToClipboard(normalizedText);
                if (onClick) {
                    onClick(normalizedText);
                }
            } },
            React.createElement(FontAwesomeIcon, { icon: faCopy }))));
});
var templateObject_1, templateObject_2;

==> rendition-14.9.0.tgz: package/dist_esm5/components/Copy/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import { faCopy } from '@fortawesome/free-regular-svg-icons/faCopy';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import copyToClipboard from 'copy-to-clipboard';
import * as React from 'react';
import styled from 'styled-components';
import { px } from '../../utils';
import { Box } from '../Box';
import { Flex } from '../Flex';
var ClipboardContainer = styled(Box)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tcursor: pointer;\n\t/* We want the clipboard icon slightly smaller, but it should be the same height as normal text so it lines up nicely */\n\tfont-size: 0.875em;\n\tline-height: ", ";\n"], ["\n\tcursor: pointer;\n\t/* We want the clipboard icon slightly smaller, but it should be the same height as normal text so it lines up nicely */\n\tfont-size: 0.875em;\n\tline-height: ", ";\n"])), function (props) { return px(props.theme.lineHeight * props.theme.font[1]); });
var CopyContainer = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\t", " {\n\t\tdisplay: ", ";\n\t}\n\n\t&:hover {\n\t\t", " {\n\t\t\tdisplay: inline;\n\t\t}\n\t}\n"], ["\n\t", " {\n\t\tdisplay: ", ";\n\t}\n\n\t&:hover {\n\t\t", " {\n\t\t\tdisplay: inline;\n\t\t}\n\t}\n"])), ClipboardContainer, function (props) { return (props.show === 'always' ? 'inline' : 'none'); }, ClipboardContainer);
export default (function (_a) {
    var content = _a.content, show = _a.show, children = _a.children, onClick = _a.onClick, otherProps = __rest(_a, ["content", "show", "children", "onClick"]);
    var normalizedText = (content || '').toString().trim();
    return (React.createElement(CopyContainer, __assign({ show: !!children ? show : 'always', flexDirection: "row", flexWrap: "nowrap" }, otherProps),
        children,
        React.createElement(ClipboardContainer, { mx: 2, tooltip: { text: 'Copied!', trigger: 'click' }, onClick: function (e) {
                e.stopPropagation();
                e.preventDefault();
                copyToClipboard(normalizedText);
                if (onClick) {
                    onClick(normalizedText);
                }
            } },
            React.createElement(FontAwesomeIcon, { icon: faCopy }))));
});
var templateObject_1, templateObject_2;
